summaryrefslogtreecommitdiffstats
path: root/tdecore/kuniqueapplication.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:21:02 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:21:02 -0600
commit8e7816b2f9f62a2df094c5b2a7aa5abb6bc1226a (patch)
tree19ff5ecf5e6b5168e5503677f18b85f3dfa91f95 /tdecore/kuniqueapplication.h
parent5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0 (diff)
downloadtdelibs-8e7816b2f9f62a2df094c5b2a7aa5abb6bc1226a.tar.gz
tdelibs-8e7816b2f9f62a2df094c5b2a7aa5abb6bc1226a.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kuniqueapplication.h')
-rw-r--r--tdecore/kuniqueapplication.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdecore/kuniqueapplication.h b/tdecore/kuniqueapplication.h
index e9dca8d99..eaa79dc57 100644
--- a/tdecore/kuniqueapplication.h
+++ b/tdecore/kuniqueapplication.h
@@ -42,10 +42,10 @@ class KUniqueApplicationPrivate;
* option (see TDECmdLineArgs::addTempFileOption()), to delete tempfiles after use.
* Add X-TDE-HasTempFileOption=true to the .desktop file to indicate this.
*
- * @see KApplication DCOPObject
+ * @see TDEApplication DCOPObject
* @author Preston Brown <pbrown@kde.org>
*/
-class TDECORE_EXPORT KUniqueApplication : public KApplication, public DCOPObject
+class TDECORE_EXPORT KUniqueApplication : public TDEApplication, public DCOPObject
{
Q_OBJECT
public:
@@ -56,7 +56,7 @@ public:
* styles. This is only useful to applications that do not display a GUI
* normally. If you do create an application with @p allowStyles set to false
* it normally runs in the background but under special circumstances
* displays widgets. Call KApplication::enableStyles() before
* displaying any widgets.
* @param GUIenabled Set to false to disable all GUI stuff. This implies
* no styles either.
@@ -82,7 +82,7 @@ public:
* styles. This is only useful to applications that do not display a GUI
* normally. If you do create an application with @p allowStyles set to false
* it normally runs in the background but under special circumstances
* displays widgets. Call KApplication::enableStyles() before
* displaying any widgets.
* @param configUnique If true, the uniqueness of the application will
* depend on the value of the "MultipleInstances"
@@ -56,7 +56,7 @@ public:
* normally. If you do create an application with @p allowStyles set to false
* it normally runs in the background but under special circumstances
- * displays widgets. Call KApplication::enableStyles() before
+ * displays widgets. Call TDEApplication::enableStyles() before
* displaying any widgets.
* @param GUIenabled Set to false to disable all GUI stuff. This implies
@@ -82,7 +82,7 @@ public:
* normally. If you do create an application with @p allowStyles set to false
* it normally runs in the background but under special circumstances
- * displays widgets. Call KApplication::enableStyles() before
+ * displays widgets. Call TDEApplication::enableStyles() before
* displaying any widgets.
* @param configUnique If true, the uniqueness of the application will